@@ -17,25 +17,29 @@ limitations under the License.
 package actuators
 
 import (
+	"encoding/json"
 	"testing"
 
-	"github.com/ghodss/yaml"
-	clusterv1 "github.com/openshift/cluster-api/pkg/apis/cluster/v1alpha1"
-	machinev1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
-	"github.com/openshift/cluster-api/pkg/client/clientset_generated/clientset/fake"
+	machinev1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/kubernetes/scheme"
+	"k8s.io/klog"
 	"k8s.io/utils/pointer"
-	clusterproviderv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1alpha1"
-	machineproviderv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1beta1"
+	providerspecv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1beta1"
 	controllerfake "sigs.k8s.io/controller-runtime/pkg/client/fake"
 )
 
-func providerSpecFromMachine(in *machineproviderv1.AzureMachineProviderSpec) (*machinev1.ProviderSpec, error) {
-	bytes, err := yaml.Marshal(in)
+func init() {
+	if err := machinev1.AddToScheme(scheme.Scheme); err != nil {
+		klog.Fatal(err)
+	}
+}
+
+func providerSpecFromMachine(in *providerspecv1.AzureMachineProviderSpec) (*machinev1.ProviderSpec, error) {
+	bytes, err := json.Marshal(in)
 	if err != nil {
 		return nil, err
 	}
@@ -45,7 +49,7 @@ func providerSpecFromMachine(in *machineproviderv1.AzureMachineProviderSpec) (*m
 }
 
 func newMachine(t *testing.T) *machinev1.Machine {
-	machineConfig := machineproviderv1.AzureMachineProviderSpec{}
+	machineConfig := providerspecv1.AzureMachineProviderSpec{}
 	providerSpec, err := providerSpecFromMachine(&machineConfig)
 	if err != nil {
 		t.Fatalf("error encoding provider config: %v", err)
@@ -64,10 +68,8 @@ func TestNilClusterScope(t *testing.T) {
 	m := newMachine(t)
 	params := MachineScopeParams{
 		AzureClients: AzureClients{},
-		Cluster:      nil,
 		CoreClient:   nil,
 		Machine:      m,
-		Client:       fake.NewSimpleClientset(m).MachineV1beta1(),
 	}
 	_, err := NewMachineScope(params)
 	if err != nil {
@@ -82,19 +84,22 @@ func TestCredentialsSecretSuccess(t *testing.T) {
 			Namespace: "dummyNamespace",
 		},
 		Data: map[string][]byte{
-			"azure_subscription_id": []byte("dummySubID"),
-			"azure_client_id":       []byte("dummyClientID"),
-			"azure_client_secret":   []byte("dummyClientSecret"),
-			"azure_tenant_id":       []byte("dummyTenantID"),
-			"azure_resourcegroup":   []byte("dummyResourceGroup"),
-			"azure_region":          []byte("dummyRegion"),
-			"azure_resource_prefix": []byte("dummyClusterName"),
+			AzureCredsSubscriptionIDKey: []byte("dummySubID"),
+			AzureCredsClientIDKey:       []byte("dummyClientID"),
+			AzureCredsClientSecretKey:   []byte("dummyClientSecret"),
+			AzureCredsTenantIDKey:       []byte("dummyTenantID"),
+			AzureCredsResourceGroupKey:  []byte("dummyResourceGroup"),
+			AzureCredsRegionKey:         []byte("dummyRegion"),
+			AzureResourcePrefix:         []byte("dummyClusterName"),
 		},
 	}
-	scope := &Scope{Cluster: &clusterv1.Cluster{}, ClusterConfig: &clusterproviderv1.AzureClusterProviderSpec{}}
-	err := updateScope(
+	scope := &MachineScope{
+		MachineConfig: &providerspecv1.AzureMachineProviderSpec{
+			CredentialsSecret: &corev1.SecretReference{Name: "testCredentials", Namespace: "dummyNamespace"},
+		},
+	}
+	err := updateFromSecret(
 		controllerfake.NewFakeClient(credentialsSecret),
-		&corev1.SecretReference{Name: "testCredentials", Namespace: "dummyNamespace"},
 		scope)
 	if err != nil {
 		t.Errorf("Expected New credentials secrets to succeed: %v", err)
@@ -108,20 +113,23 @@ func TestCredentialsSecretSuccess(t *testing.T) {
 		t.Errorf("Expected location to be dummyRegion but found %s", scope.Location())
 	}
 
-	if scope.Cluster.Name != "dummyClusterName" {
-		t.Errorf("Expected cluster name to be dummyClusterName but found %s", scope.Cluster.Name)
+	if scope.MachineConfig.Name != "dummyClusterName" {
+		t.Errorf("Expected cluster name to be dummyClusterName but found %s", scope.MachineConfig.Name)
 	}
 
-	if scope.ClusterConfig.ResourceGroup != "dummyResourceGroup" {
-		t.Errorf("Expected resourcegroup to be dummyResourceGroup but found %s", scope.ClusterConfig.ResourceGroup)
+	if scope.MachineConfig.ResourceGroup != "dummyResourceGroup" {
+		t.Errorf("Expected resourcegroup to be dummyResourceGroup but found %s", scope.MachineConfig.ResourceGroup)
 	}
 }
 
 func testCredentialFields(credentialsSecret *corev1.Secret) error {
-	scope := &Scope{Cluster: &clusterv1.Cluster{}, ClusterConfig: &clusterproviderv1.AzureClusterProviderSpec{}}
-	return updateScope(
+	scope := &MachineScope{
+		MachineConfig: &providerspecv1.AzureMachineProviderSpec{
+			CredentialsSecret: &corev1.SecretReference{Name: "testCredentials", Namespace: "dummyNamespace"},
+		},
+	}
+	return updateFromSecret(
 		controllerfake.NewFakeClient(credentialsSecret),
-		&corev1.SecretReference{Name: "testCredentials", Namespace: "dummyNamespace"},
 		scope)
 }
 
@@ -192,15 +200,15 @@ func testCredentialSecret() *corev1.Secret {
 	}
 }
 
-func testProviderSpec() *machineproviderv1.AzureMachineProviderSpec {
-	return &machineproviderv1.AzureMachineProviderSpec{
+func testProviderSpec() *providerspecv1.AzureMachineProviderSpec {
+	return &providerspecv1.AzureMachineProviderSpec{
 		Location:          "test",
 		ResourceGroup:     "test",
 		CredentialsSecret: &corev1.SecretReference{Name: "testCredentials", Namespace: "dummyNamespace"},
 	}
 }
 
-func testMachineWithProviderSpec(t *testing.T, providerSpec *machineproviderv1.AzureMachineProviderSpec) *machinev1.Machine {
+func testMachineWithProviderSpec(t *testing.T, providerSpec *providerspecv1.AzureMachineProviderSpec) *machinev1.Machine {
 	providerSpecWithValues, err := providerSpecFromMachine(providerSpec)
 	if err != nil {
 		t.Fatalf("error encoding provider config: %v", err)
@@ -226,8 +234,6 @@ func TestPersistMachineScope(t *testing.T) {
 
 	params := MachineScopeParams{
 		Machine:    machine,
-		Cluster:    nil,
-		Client:     fake.NewSimpleClientset(machine).MachineV1beta1(),
 		CoreClient: controllerfake.NewFakeClientWithScheme(scheme.Scheme, testCredentialSecret()),
 	}
 
@@ -248,24 +254,23 @@ func TestPersistMachineScope(t *testing.T) {
 	scope.Machine.Status.Addresses = make([]corev1.NodeAddress, len(nodeAddresses))
 	copy(nodeAddresses, scope.Machine.Status.Addresses)
 
+	if err := params.CoreClient.Create(scope.Context, scope.Machine); err != nil {
+		t.Fatal(err)
+	}
+
 	if err = scope.Persist(); err != nil {
 		t.Errorf("Expected MachineScope.Persist to success, got error: %v", err)
 	}
 
-	updatedMachine, err := params.Client.Machines(params.Machine.Namespace).Get(params.Machine.Name, metav1.GetOptions{})
-	if err != nil {
-		t.Errorf("Unable to get updated machine: %v", err)
+	if !equality.Semantic.DeepEqual(scope.Machine.Status.Addresses, nodeAddresses) {
+		t.Errorf("Expected node addresses to equal, updated addresses %#v, expected addresses: %#v", scope.Machine.Status.Addresses, nodeAddresses)
 	}
 
-	if !equality.Semantic.DeepEqual(updatedMachine.Status.Addresses, nodeAddresses) {
-		t.Errorf("Expected node addresses to equal, updated addresses %#v, expected addresses: %#v", updatedMachine.Status.Addresses, nodeAddresses)
+	if scope.Machine.Annotations["test"] != "testValue" {
+		t.Errorf("Expected annotation 'test' to equal 'testValue', got %q instead", scope.Machine.Annotations["test"])
 	}
 
-	if updatedMachine.Annotations["test"] != "testValue" {
-		t.Errorf("Expected annotation 'test' to equal 'testValue', got %q instead", updatedMachine.Annotations["test"])
-	}
-
-	machineStatus, err := machineproviderv1.MachineStatusFromProviderStatus(updatedMachine.Status.ProviderStatus)
+	machineStatus, err := providerspecv1.MachineStatusFromProviderStatus(scope.Machine.Status.ProviderStatus)
 	if err != nil {
 		t.Errorf("failed to get machine provider status: %v", err)
 	}
@@ -278,7 +283,7 @@ func TestPersistMachineScope(t *testing.T) {
 }
 
 func TestNewMachineScope(t *testing.T) {
-	machineConfigNoValues := &machineproviderv1.AzureMachineProviderSpec{
+	machineConfigNoValues := &providerspecv1.AzureMachineProviderSpec{
 		CredentialsSecret: &corev1.SecretReference{Name: "testCredentials", Namespace: "dummyNamespace"},
 	}
 
@@ -305,19 +310,17 @@ func TestNewMachineScope(t *testing.T) {
 	for _, tc := range testCases {
 		scope, err := NewMachineScope(MachineScopeParams{
 			Machine:    tc.machine,
-			Cluster:    nil,
-			Client:     fake.NewSimpleClientset(tc.machine).MachineV1beta1(),
 			CoreClient: controllerfake.NewFakeClientWithScheme(scheme.Scheme, tc.secret),
 		})
 		if err != nil {
 			t.Fatalf("Unexpected error %v", err)
 		}
 
-		if scope.ClusterConfig.Location != tc.expectedLocation {
-			t.Errorf("Expected %v, got: %v", tc.expectedLocation, scope.ClusterConfig.Location)
+		if scope.MachineConfig.Location != tc.expectedLocation {
+			t.Errorf("Expected %v, got: %v", tc.expectedLocation, scope.MachineConfig.Location)
 		}
-		if scope.ClusterConfig.ResourceGroup != tc.expectedResourceGroup {
-			t.Errorf("Expected %v, got: %v", tc.expectedResourceGroup, scope.ClusterConfig.ResourceGroup)
+		if scope.MachineConfig.ResourceGroup != tc.expectedResourceGroup {
+			t.Errorf("Expected %v, got: %v", tc.expectedResourceGroup, scope.MachineConfig.ResourceGroup)
 		}
 	}
 }
